@@ -38,7 +38,9 @@ lmWithCov<-function(f,x) {
 	class(out)<-"lmWithCov"
 	out
 }
-# @internal
-formula.lmWithCov<-function(x) {
+
+#' @keywords internal
+#' @export
+formula.lmWithCov<-function(x, ...) {
 	x$formula
 }
