@@ -14,20 +14,20 @@ test_that("raise error on incorrect fit function", {
 
 test_that("complete graph should be a ggplot object", {
   p1<-plot(da.attitude)
-  expect_true(ggplot2::is.ggplot(p1))
+  expect_true(ggplot2::is_ggplot(p1))
 })
 
 test_that("complete graph without facetshould be a ggplot object", {
   p1<-plot(da.attitude,which.graph = "complete_no_facet")
-  expect_true(ggplot2::is.ggplot(p1))
+  expect_true(ggplot2::is_ggplot(p1))
 })
 
 test_that("conditional graph without facetshould be a ggplot object", {
   p1<-plot(da.attitude,which.graph = "conditional")
-  expect_true(ggplot2::is.ggplot(p1))
+  expect_true(ggplot2::is_ggplot(p1))
 })
 
 test_that("general graph without facetshould be a ggplot object", {
   p1<-plot(da.attitude,which.graph = "general")
-  expect_true(ggplot2::is.ggplot(p1))
+  expect_true(ggplot2::is_ggplot(p1))
 })
